function [] = plot()
%PLOT Plots or updates the time of arrival points.
%   If the plot already exists and is valid, the points only get updated.
%   Otherwise the plot will be initialized
%

global artoaGui artoaWorkspace artoaDataInput;

%% Get all required values
% create color vector
c = artoaWorkspace.toaData.correlationHeight;

if artoaWorkspace.hideDeletedDataPoints
    % get all toa that are considered valid by temperature and pressure
    % selection
    temperature = repmat(artoaWorkspace.statusTemperature, length(artoaDataInput.rfb.VARIABLE_LIST.time_of_arrival), 1);
    pressure = repmat(artoaWorkspace.statusPressure, length(artoaDataInput.rfb.VARIABLE_LIST.time_of_arrival), 1);
    selection = temperature == 1 & pressure == 1 & artoaWorkspace.toaData.status ~= 2;
    x = artoaWorkspace.toaData.toaDate(selection);
    y = artoaWorkspace.toaData.toa(selection);
    c = c(selection, :);
    clear temperature pressure selection;
else
    x = artoaWorkspace.toaData.toaDate;
    y = artoaWorkspace.toaData.toa;
end

%% If the plot exists, just update the values

if isfield(artoaGui.editTimeOfArrival, 'scatterTimeOfArrival') ...
        && isvalid(artoaGui.editTimeOfArrival.scatterTimeOfArrival)
    artoaGui.editTimeOfArrival.scatterTimeOfArrival.XData = x;
    artoaGui.editTimeOfArrival.scatterTimeOfArrival.YData = y;
    artoaGui.editTimeOfArrival.scatterTimeOfArrival.CData = c;
    % update applied sound sources
    artoa.controller.edit.timeOfArrival.plotAppliedSoundsources();
    artoa.controller.edit.timeOfArrival.plotSoundsourceToaFromGps(artoaWorkspace.filteredSoundsources);
    artoa.controller.edit.timeOfArrival.applyToaAxesToGpsAndSoundsources();
    artoa.controller.edit.timeOfArrival.createSoundsourceColorsPanel();
    linkaxes([ ...
        artoaGui.editTimeOfArrival.axesScatterTimeOfArrival, ...
        artoaGui.editTimeOfArrival.axesToaFromGps, ...
        artoaGui.editTimeOfArrival.axesAppliedSoundsources ...
    ]);
    % force toa scatter to be current axes of figure
    artoaGui.figures.editTimeOfArrival.CurrentAxes = artoaGui.editTimeOfArrival.axesScatterTimeOfArrival;
    zoom(artoaGui.figures.editTimeOfArrival, 'reset');
    return
end

%% Create a new plot if non existent

artoaGui.editTimeOfArrival.axesScatterTimeOfArrival = axes(artoaGui.figures.editTimeOfArrival);
hold(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival, 'on');

% get all points that are not deleted
artoaGui.editTimeOfArrival.scatterTimeOfArrival = scatter( ...
    artoaGui.editTimeOfArrival.axesScatterTimeOfArrival, ...
    x, ...
    y, ...
    artoa.data.getMember(artoaDataInput, {'ini', 'view', 'toapointsize'}, 36), ...
    c, ...
    'filled' ...
);

%% Set colormap
artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.CLim = [0, 255];
colormap(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival, colormap);

%% Setup gui

grid on;

% set background color
set(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival, 'Color', [.3 .3 .3], 'XColor', 'blue', 'YColor', 'blue');

% set plot title
titleVal = [ ...
    'Project: ' artoaWorkspace.float.projectname ...
    ' FloatId: ' num2str(artoaWorkspace.float.floatname) ...
    ' Cycle: ' num2str(artoaWorkspace.float.cycle(1)) ...
    ' - Time of arrival' ...
];
titleHandle = title(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival, titleVal, 'FontSize', 10);
set(titleHandle, 'Color', 'blue');

% set x and y label
xlabel(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival, 'Message Date', 'FontSize', 10);
ylabel(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival, 'Time of arrival rel. to window start time', 'FontSize', 10);

%% Setup GPS information plot
artoa.controller.edit.timeOfArrival.plotSoundsourceToaFromGps(artoaWorkspace.filteredSoundsources);

%% Plot applied sound sources
artoa.controller.edit.timeOfArrival.plotAppliedSoundsources();

%% Adjust the limits of TOA to the other ones
artoa.controller.edit.timeOfArrival.applyToaAxesToGpsAndSoundsources();

%% Link toa, gps information and applied sound sources plot
linkaxes([ ...
    artoaGui.editTimeOfArrival.axesScatterTimeOfArrival, ...
    artoaGui.editTimeOfArrival.axesToaFromGps, ...
    artoaGui.editTimeOfArrival.axesAppliedSoundsources ...
]);

hold(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival, 'off');


end

